from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

DSP_Microchip_DSPIC33 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'DSPIC33EP256MU810-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33EP256MU810-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70616g.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33EP256MU810-xPT\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/PMA5/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='AN28/PWM3L/PMD4/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/PMA4/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/PMA3/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PMA2/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='RA0/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RB5/AN5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB4/AN4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB3/AN3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2/AN2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB1/AN1/PGEC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RB0/AN0/PGED3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RB6/AN6/PGEC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='RB7/AN7/PGED1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA9/VREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA10/VREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RB8/PMA6/AN8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RB9/PMA7/AN9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB10/PMA13/AN10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB11/PMA12/AN11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RA1/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RB12/PMA11/AN12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RB13/PMA10/AN13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB14/PMA1/AN14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB15/PMA0/AN15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='SDA2/PMA9/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SCL2/PMA8/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='D-/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='D+/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RA2/ASCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RA3/ASDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC1/PWM5L/AN16',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RA4/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RA5/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='RC12/OSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RC15/CLKO/OSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='RTCC/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='ASDA1/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2/PWM5H/AN17',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='ASCL1/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='INT0/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='RC13/SOSCI/PGED2',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='RC14/T1CK/SOSCO/PGEC2',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='DPH/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PMBE/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC3/PWM6L/AN18',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PMWR/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PMRD/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC4/PWM6H/AN19',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='RA6/AN22',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='RA7/AN23',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='AN24/PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='AN25/PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AN26/PWM2L/PMD2/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='AN27/PWM2H/PMD3/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128GP204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128GP204'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70292G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128GP204\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128GP804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128GP804'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70292G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128GP804\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AN12/DAC1RP/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN11/DAC1RN/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN10/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN9/DAC1LN/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128MC204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128MC204'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128MC204\n\n16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128MC804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128MC804'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128MC804\n\n16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PWM1H2/DAC1RP/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PWM1L2/DAC1RN/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PWM1H1/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM1L/DAC1LN/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ256MC710A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ256MC710A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ256MC710A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ32GP304', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ32GP304'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70292G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ32GP304\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ32MC304', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ32MC304'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ32MC304\n\n16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64GP204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64GP204'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70292G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64GP204\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64GP306A-IMR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64GP306A-IMR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70593d.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64GP306A-IMR\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='COFS/RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AN5/IC8/CN7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AN4/IC7/CN6/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AN3/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PGEC3/AN1/Vref-/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PGED3/AN0/Vref+/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PGEC1/AN6/OCFA/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PGED1/AN7/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='~{U2CTS}/AN8/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TMS/AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TDO/AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='TCK/AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDI/AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{U2RTS}/AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='U2RX/SDA2/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='U2TX/SCL2/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='U1TX/SDO1/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='U1RX/SDI1/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{U1RTS}/SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='IC1/INT1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IC2/~{U1CTS}/INT2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IC3/INT3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IC4/INT4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PGED2/SOSCI/T4CK/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='OC5/IC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='OC6/IC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='OC8/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='CSCK/RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='CSDI/RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='CSDO/RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64GP804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64GP804'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC33', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70292G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64GP804\n\n16-bit Digital Signal Controller Microchip dsPIC33', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AN12/DAC1RP/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AN11/DAC1RN/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AN10/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AN9/DAC1LN/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64MC204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64MC204'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64MC204\n\n16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64MC802-xSP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64MC802-xSP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64MC802-xSP\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OSC2/CLKO/CN29/PMA0/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SOSCI/RP4/CN1/PMBE/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SOSCO/T1CK/CN0/PMA1/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TCK/PWM2H1/SCL1/RP8/CN22/PMD4/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TDO/PWM2L1/SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='PGED2/TDI/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC2/TMS/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PWM1H2/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PWM1L2/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PWM1L1/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OSC1/CLKI/CN30/RA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64MC804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64MC804'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70291G.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64MC804\n\n16-bit Digital Signal Controller Microchip dsPIC Motor Control', 'pins':[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PWM1H2/DAC1RP/RP12/CN14/PMD0/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PWM1L2/DAC1RN/RP13/CN13/PMRD/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TMS/PMA10/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TCK/PMA7/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PWM1H1/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PWM1L/DAC1LN/RP15/CN11/PMCS1/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TDO/PMA8/RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TDI/PMA9/RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128MC510A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128MC510A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128MC510A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ128MC710A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ128MC710A'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ128MC710A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ256MC510A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ256MC510A'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ256MC510A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64MC510A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64MC510A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64MC510A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSPIC33FJ64MC710A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSPIC33FJ64MC710A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'16-bit Digital Signal Controller Microchip dsPIC', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/70594C.pdf', 'search_text':'/usr/share/kicad/symbols/DSP_Microchip_DSPIC33.kicad_sym\nDSPIC33FJ64MC710A\n\n16-bit Digital Signal Controller Microchip dsPIC', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SCK2/CN8/RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PWM3L/RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDI2/CN9/RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDO2/CN10/RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SS2}/CN11/RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='TMS/RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AN20/~{FLTA}/INT1/RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AN21/~{FLTB}/INT2/RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AN5/QEB/CN7/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AN4/QEA/CN6/RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='AN3/INDX/CN5/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AN2/~{SS1}/CN4/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC3/AN1/CN3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED3/AN0/CN2/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC1/AN6/OCFA/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED1/AN7/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VREF-/RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VREF+/RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PWM3H/RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AN8/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AN9/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AN10/RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AN11/RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='TCK/RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='~{U2RTS}/RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PWM4L/RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{U2CTS}/RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AN12/RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AN13/RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AN14/RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AN15/OCFB/CN12/RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IC7/~{U1CTS}/CN20/RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IC8/~{U1RTS}/CN21/RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='U2RX/CN17/RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PWM4H/RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='U2TX/CN18/RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='U1TX/RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='U1RX/RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='SDO1/RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='SDI1/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='SCK1/INT0/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='SDA1/RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='SCL1/RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='SCL2/RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SDA2/RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AN16/T2CK/T7CK/RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='TDI/RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='TDO/RA5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='OSC1/CLKIN/RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='OSC2/CLKO/RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='INT3/RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='INT4/RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IC1/RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IC2/RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AN17/T3CK/T6CK/RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IC3/RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IC4/RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='OC1/RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PGED2/SOSCI/CN1/RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PGEC2/SOSCO/T1CK/CN0/RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='OC2/RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='OC3/RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='OC4/RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IC5/RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AN18/T4CK/T9CK/RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IC6/CN19/RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='OC5/CN13/RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='OC6/CN14/RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='OC7/CN15/RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='OC8/UPDN/CN16/RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='C1RX/RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='C1TX/RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='C2TX/RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AN19/T5CK/T8CK/RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='C2RX/RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='AN22/CN22/RA6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='AN23/CN23/RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PWM1L/RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PWM1H/RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PWM2L/RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PWM2H/RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])